pub struct ColorPicker {
pub(crate) id: EmbedderControlId,
pub(crate) current_color: Option<RgbColor>,
pub(crate) position: DeviceIntRect,
pub(crate) constellation_proxy: ConstellationProxy,
pub(crate) response_sent: bool,
}Expand description
Represents a dialog triggered by clicking a <input type=color> element.
Fields
id: EmbedderControlIdcurrent_color: Option<RgbColor>position: DeviceIntRectconstellation_proxy: ConstellationProxyresponse_sent: boolImplementations
Sourceimpl ColorPicker
impl ColorPicker
Sourcepub fn id(&self) -> EmbedderControlId
pub fn id(&self) -> EmbedderControlId
Return the EmbedderControlId associated with this element.
Sourcepub fn position(&self) -> DeviceIntRect
pub fn position(&self) -> DeviceIntRect
Get the area occupied by the <input> element that triggered the prompt.
The embedder should use this value to position the prompt that is shown to the user.
Sourcepub fn current_color(&self) -> Option<RgbColor>
pub fn current_color(&self) -> Option<RgbColor>
Get the currently selected color for this ColorPicker. This is initially the selected color
before the picker is opened.
Sourcepub fn select(&mut self, color: Option<RgbColor>)
pub fn select(&mut self, color: Option<RgbColor>)
Set the selected color for this ColorPicker. Passing None behaves as if the default
color was selected.
Sourcepub fn submit(self)
pub fn submit(self)
Resolve the prompt with the options that have been selected by calling Self::select previously.