pub struct SelectElement {
pub(crate) id: EmbedderControlId,
pub(crate) position: DeviceIntRect,
pub(crate) constellation_proxy: ConstellationProxy,
pub(crate) select_element_request: SelectElementRequest,
pub(crate) response_sent: bool,
}Expand description
Represents a dialog triggered by clicking a <select> element.
Fields
id: EmbedderControlIdposition: DeviceIntRectconstellation_proxy: ConstellationProxyselect_element_request: SelectElementRequestresponse_sent: boolImplementations
Sourceimpl SelectElement
impl SelectElement
Sourcepub fn id(&self) -> EmbedderControlId
pub fn id(&self) -> EmbedderControlId
Return the EmbedderControlId associated with this element.
Sourcepub fn position(&self) -> DeviceIntRect
pub fn position(&self) -> DeviceIntRect
Return the area occupied by the <select> element that triggered the prompt.
The embedder should use this value to position the prompt that is shown to the user.
Sourcepub fn options(&self) -> &[SelectElementOptionOrOptgroup]
pub fn options(&self) -> &[SelectElementOptionOrOptgroup]
Consecutive <option> elements outside of an <optgroup> will be combined
into a single anonymous group without a label.
Sourcepub fn select(&mut self, selected_options: Vec<usize>)
pub fn select(&mut self, selected_options: Vec<usize>)
Set the options that are selected.
selected_options is a vector of indices into the array returned by Self::options.
If other options have previously been selected, this set of options will replace them.
Sourcepub fn selected_options(&self) -> Vec<usize>
pub fn selected_options(&self) -> Vec<usize>
Get the currently selected options, represented by indices into the array
returned by Self::options.
Sourcepub fn allow_select_multiple(&self) -> bool
pub fn allow_select_multiple(&self) -> bool
Whether this <select> supports selecting multiple options.
Sourcepub fn submit(self)
pub fn submit(self)
Resolve the prompt with the options that have been selected by calling Self::select previously.