ColorPicker

Struct ColorPicker 

pub struct ColorPicker {
    pub(crate) id: EmbedderControlId,
    pub(crate) current_color: Option<RgbColor>,
    pub(crate) position: DeviceIntRect,
    pub(crate) constellation_proxy: ConstellationProxy,
    pub(crate) response_sent: bool,
}
Represents a dialog triggered by clicking a <input type=color> element.

Fields

id: EmbedderControlIdcurrent_color: Option<RgbColor>position: DeviceIntRectconstellation_proxy: ConstellationProxyresponse_sent: bool

Implementations

Source

impl ColorPicker

pub fn id(&self) -> EmbedderControlId

Return the EmbedderControlId associated with this element.

pub fn position(&self) -> DeviceIntRect

Get the area occupied by the <input> element that triggered the prompt.

The embedder should use this value to position the prompt that is shown to the user.

pub fn current_color(&self) -> Option<RgbColor>

Get the currently selected color for this ColorPicker. This is initially the selected color before the picker is opened.

pub fn select(&mut self, color: Option<RgbColor>)

Set the selected color for this ColorPicker. Passing None behaves as if the default color was selected.

pub fn submit(self)

Resolve the prompt with the options that have been selected by calling Self::select previously.