pub struct CreateNewWebViewRequest {
pub(crate) servo: Servo,
pub(crate) responder: IpcResponder<Option<NewWebViewDetails>>,
}Expand description
A request from Servo to embedder to open a new auxiliary WebView, typically
triggered by page content calling DOM APIs like window.open().
Refer to the documentation of WebViewDelegate::request_create_new for more information.
Fields
servo: Servoresponder: IpcResponder<Option<NewWebViewDetails>>Implementations
Sourceimpl CreateNewWebViewRequest
impl CreateNewWebViewRequest
Sourcepub fn builder(
self,
rendering_context: Rc<dyn RenderingContext>,
) -> WebViewBuilder
pub fn builder( self, rendering_context: Rc<dyn RenderingContext>, ) -> WebViewBuilder
Returns a WebViewBuilder that can be used to create a new auxiliary WebView.