pub struct ProtocolHandlerRegistration {
pub scheme: String,
pub url: Url,
pub register_or_unregister: RegisterOrUnregister,
}Expand description
A request to register or unregister a custom handler for a scheme. See https://html.spec.whatwg.org/multipage/#custom-handlers
Fields
scheme: StringThe scheme for which the hander is being registered or unregistered.
url: UrlThe URL to navigate to when loading resources for the given ‘scheme’. The string “%s” in this URL is used as a placeholder. It will be replaced by the URL of the resource to be handled.
register_or_unregister: RegisterOrUnregisterWhether this request is for a new registration or unregistering a previously registered handler.